#
# spec file for package python-WebTest
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-WebTest
Version:        2.0.18
Release:        5.8
Url:            http://webtest.pythonpaste.org/
Summary:        Helper to test WSGI applications
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/W/WebTest/WebTest-%{version}.zip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-PasteDeploy
BuildRequires:  python-WSGIProxy2
BuildRequires:  python-base
BuildRequires:  python-beautifulsoup4
BuildRequires:  python-cssselect
BuildRequires:  python-mock
BuildRequires:  python-pyquery
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-waitress
BuildRequires:  unzip
# Documentation build requirements:
BuildRequires:  python-Sphinx
# Test build requirements:
BuildRequires:  python-WebOb
BuildRequires:  python-coverage
BuildRequires:  python-nose
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-unittest2
%endif
Requires:       python-WebOb >= 1.2
Requires:       python-beautifulsoup4
Requires:       python-six
Requires:       python-waitress
Provides:       python-webtest = %{version}
Obsoletes:      python-webtest < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This wraps any WSGI application and makes it easy to send test
requests to that application, without starting up an HTTP server.

This provides convenient full-stack testing of applications written
with any WSGI-compatible framework.

%package doc
Summary:        Helper to test WSGI applications - Documentation
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n WebTest-%{version}
# remove version limitation for nose
sed -i 's/nose<1\.3\.0/nose/' setup.py

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%if 0%{?suse_version} > 1110
%check
python setup.py -q test
%endif

%files
%defattr(-,root,root,-)
%doc README.rst
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc build/sphinx/html

%changelog
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 2.0.18:
  * Avoid deprecation warning with py3.4
- additional changes from version 2.0.17:
  * Properly check for default cookiejar arguments [Julian Berman]
  * Avoid raising encoding errors from debugapp (needed to use with
    WSGIProxy2) [Laurence Rowe]
- additional changes from version 2.0.16:
  * Fixed #110. Forced values for Radio inputs are no longer
    ignored by value property on get. [bayprogrammer]
  * Added method TestApp.set_parser_features to change the
    parser_features used by BeautifulSoup. [tomasmoreyra]
  * Added app.set_cookie [luhn]
- additional changes from version 2.0.15:
  * Fixed #73. Python < 2.6.5 does not support unicode as keyword
    arguments names. [Stepan Kolesnik]
  * Fixed #84 Application cookies for localhost are no longer
    ignored [gawel]
  * Fixed #89 remove WSGIWarning: You are not supposed to send a
    body in a DELETE request because we now have a good reason for
    that. See http://bit.ly/1tb3yxW [gawel]
  * Fixed #92 You can now override TestApp.JSONEncoder to use a
    custom encoder [gawel]
  * Fixed #93 Support basic authentication [gawel]
  * Fixed #103 Broken "Edit me on GitHub" links in documentation
    [gawel]
  * Fixed #106 Make wrapping the app in the lint middleware
    optional [dmlayton]
  * Fixed #107 Explicit error message when WSGIProxy2 is not
    installer [gawel]
  * Fixed #108 cgi.parse_qsl is pending deprecation [gawel]
- additional changes from version 2.0.14:
  * Allow .select() on <select>s and <select multiple>s. [Markus
    Bertheau]
- additional changes from version 2.0.13:
  * Allow selecting <select> options by text [Markus Bertheau]
- additional changes from version 2.0.12:
  * Ignore the value attribute of file inputs [Markus Bertheau]
  * Allow selecting the form submit button by its value [Markus
    Bertheau]
- remove version limitation for nose
- pass -q to test to avoid spamming the build log
* Mon Jan 13 2014 dmueller@suse.com
- update to 2.0.11:
  * Depend on unittest2 only for Python versions lower than 2.7
  * Add an optional parameter to TestApp, allowing the user to
  specify the parser used by BeautifulSoup
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 2.0.9
  * Make sure Upload.content_type is not ignored
    https://github.com/Pylons/webtest/pull/88
* Tue Sep 17 2013 dmueller@suse.com
- update to 2.0.7:
  * Detect JSON if mimetype ends with +json, such as application/vnd.webtest+json
  * Fixed #72. Use WSGIServer new api even if there waitress has backward compat.
  * Fixed #50. Corrected default value for the delete params argument.
  * Be sure to decode the content if it is gziped before returning it
* Mon Jun 10 2013 dmueller@suse.com
- update to 2.0.6:
- fixed #64. cookiejar api has changed in python3.3 [gawel]
- allow to use a fixed StopableWSGIServer [gawel]
- Do not alter the BeautifulSoup object when parsing forms. [Georges
- Remove first newline while parse textarea block, how modern browsers does.
* Mon Apr 29 2013 dmueller@suse.com
- Update to 2.0.5:
  * Correctly handle <option> elements with no value attribute
  [Marius Gedminas]
  * Ignore socket.error following StopableWSGIServer.shutdown. [Laurence Rowe]
  * <button> without type='submit' attribute is treated as Submit
  control [Andrey Lebedev].
  * Support for redirects having relative "Location" header [Andrey Lebedev]
  * Treat strings in the WSGI environment as native strings, compliant with
  PEP-3333. [wosc]
  * Allow TestResponse.click() to match HTML content again. [ender672]
  * Support secure cookies [Andrey Lebedev]
  * Added Pasword field [diarmuidbourke]
  * re-allow to use unknow field type. Like ``type="email"``. [gawel]
  * Don't let BeautifulSoup use lxml. Fix GH-51 [kmike]
  * added :meth:`webtest.response.TestResponse.maybe_follow` method [kmike]
  * drop zc.buildout usage for development, now using only virtualenv
  [Domen Kožar]
  * Backward incompatibility : Removed the ``anchor`` argument of
  :meth:`webtest.response.TestResponse.click` and the ``button`` argument of
  :meth:`webtest.response.TestResponse.clickbutton`. It is for the greater good.
  * Rewrote API documentation [Domen Kožar]
  * Added `wsgiproxy` support to do HTTP request to an URL [gawel]
  * Use BeautifulSoup4 to parse forms [gawel]
  * Added `webtest.app.TestApp.patch_json` [gawel]
  * Implement `webtest.app.TestApp.cookiejar` support and kindof keep
  `webtest.app.TestApp.cookies` functionality.  `webtest.app.TestApp.cookies`
  should be treated as read-only.
  [Domen Kožar]
  * Split Selenium integration into separate package webtest-selenium
  * Split casperjs integration into separate package webtest-casperjs
  * Test coverage improvements [harobed, cdevienne, arthru, Domen Kožar, gawel]
  * Fully implement decoding of HTML entities
* Fri Jan 11 2013 saschpe@suse.de
- Disable testsuite on SLE_11_SP2 to fix the build (unittest module
  lacks support)
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 1.4.2:
  + fix tests error due to CLRF in a tarball
- Changes from version 1.4.1:
  + add travis-ci
  + migrate repository to https://github.com/Pylons/webtest
  + Fix a typo in apps.py: selectedIndicies
  + Preserve field order during parsing (support for deform and such)
  + Allow equals sign in the cookie by spliting name-value-string pairs on the
    first ‘=’ sign as per http://tools.ietf.org/html/rfc6265#section-5.2
  + fix an error when you use AssertionError(response) with unicode chars in response
- Build HTML documentaton
- Run testsuite
- Split of doc package
* Sat Sep 22 2012 os-dev@jacraig.com
- Update to 1.4.0:
  * added webtest.ext - allow to use casperjs
- Changes from 1.3.6:
  * fix #42: Check uppercase method.
  * fix #36: Radio can use forced value.
  * fix #24: Include test fixtures.
  * fix bug when trying to print a response which contain some unicode chars
- Changes from 1.3.5:
  * fix #39: Add PATCH to acceptable methods.
- Removed dependency on python-nose and python-dtopt: these are only needed to
  run tests.
* Wed Jun  6 2012 os-dev@jacraig.com
- Update to 1.3.4:
  * fix `#33 <https://bitbucket.org/ianb/webtest/issue/33>`_ Remove
    CaptureStdout. Do nothing and break pdb
  * use OrderedDict to store fields in form. See
    `#31 <https://bitbucket.org/ianb/webtest/issue/31>`_
  * fix `#38 <https://bitbucket.org/ianb/webtest/issue/38>`_ Allow to post
    falsey values.
  * fix `#37 <https://bitbucket.org/ianb/webtest/issue/37>`_ Allow
    Content-Length: 0 without Content-Type
  * `fix #30 <https://bitbucket.org/ianb/webtest/issue/30>`_ bad link to
    pyquery documentation
  * Never catch NameError during iteration
* Tue Jan 31 2012 saschpe@suse.de
- Simplified macro usage
- Run testsuite
- Update to version 1.3.3:
  * added post_json, put_json, delete_json
  * fix #25 params dictionary of webtest.AppTest.post() does not support unicode values
- Changes from version 1.3.2:
  * improve showbrowser.
  * print_stderr fail with unicode string on python2
- Changes from version 1.3.1:
  * Added .option()
  * Full python3 compat
* Thu Sep  1 2011 saschpe@suse.de
- Don't run tests, fixes SLE build
* Thu Sep  1 2011 saschpe@suse.de
- Initial version
